Modules of PyQt-Fit
===================

.. toctree::

  mod_plot_fit
  mod_curve_fitting
  mod_bootstrap
  mod_nonparam_regression
  mod_npr_methods
  mod_kde
  mod_kde_methods
  mod_kernels
  mod_utils

